@@ -218,7 +218,7 @@ executorch.Node = class {
             for (let i = 0; i < outputs.length; i++) {
                 const output = outputs[i];
                 const value = values.map(output);
-                const name = inputs.length === 1 ? 'output' : `output.${i}`;
+                const name = outputs.length === 1 ? 'output' : `output.${i}`;
                 const argument = new executorch.Argument(name, value.value, value.type);
                 this.outputs.push(argument);
             }
@@ -570,7 +570,7 @@ xnnpack.Node = class {
             let value = ArrayBuffer.isView(obj) ? Array.from(obj) : obj;
             let type = 'attribute';
             if (name.endsWith('_id')) {
-                value = obj === -1 ? [] : [values.map(obj)];
+                value = obj === -1 || obj === 0xFFFFFFFF ? [] : [values.map(obj)];
                 type = null;
             }
             const argument = new xnnpack.Argument(name, value, type);
